@@ -7,7 +7,7 @@ from . import auth
 from . import http
 from . import engine
 
-class BasePublisher(auth.NullAuthorise):
+class BasePublisher(object):
 
     def __init__(self, request, *args, **kwargs):
         self.request = request
@@ -32,7 +32,7 @@ class BasePublisher(auth.NullAuthorise):
             return self.dispatch(request, *args, **kwargs)
 
         if api_name:
-            name = '_'.join([api_name, cls.api_name])
+            name = '%s_%s' % (api_name, cls.api_name)
         else:
             name = self.api_name
 
@@ -68,15 +68,12 @@ class BasePublisher(auth.NullAuthorise):
         self.action = action
         method = request.method.lower()
         prefix = 'object' if object_id else 'list'
-        handler = getattr(self, '_'.join([prefix, method, action]), None)
+        handler = getattr(self, '%s_%s_%s' % (prefix, method, action), None)
         if handler is None:
-            handler = getattr(self, '_'.join([prefix, action]), None)
-        # See if there's a method agnostic handler
+            # See if there's a method agnostic handler
+            handler = getattr(self, '%s_%s' % (prefix, action), None)
         if handler is None:
             raise http.Http404
-        # Permission check
-        if not self.may(request, action, object_id, **kwargs):
-            return http.HttpResponseUnauthorized()
         # Do we need to pass any of this?
         return handler(request, action=action, object_id=object_id, **kwargs)
 
@@ -87,11 +84,11 @@ class Publisher(engine.JsonEngine, BasePublisher):
         '''Return the serialiser instance to use for this request'''
         return self.serialiser
 
-    def get_object_list(self):
+    def get_object_list(self): # pragma: no cover
         '''Return the object list appropriate for this request'''
         raise NotImplementedError
 
-    def get_object(self, object_id):
+    def get_object(self, object_id): # pragma: no cover
         '''Return the object for the given id'''
         raise NotImplementedError
 
